@@ -1,4 +1,10 @@
 package Tapper::Reports::Web::Controller::Root;
+BEGIN {
+  $Tapper::Reports::Web::Controller::Root::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Reports::Web::Controller::Root::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -39,16 +45,23 @@ sub default :Path
 sub end : ActionClass('RenderView') {}
 
 
-__END__
+
+
+=pod
+
+=encoding utf-8
 
 =head1 NAME
 
-Tapper::Reports::Web::Controller::Root - Root Controller for Tapper::Reports::Web
+Tapper::Reports::Web::Controller::Root
 
 =head1 DESCRIPTION
 
 [enter your description here]
 
+=head1 NAME
+
+Tapper::Reports::Web::Controller::Root - Root Controller for Tapper::Reports::Web
 
 =head1 METHODS
 
@@ -56,7 +69,6 @@ Tapper::Reports::Web::Controller::Root - Root Controller for Tapper::Reports::We
 
 Attempt to render a view, if needed.
 
-
 =head1 AUTHOR
 
 Steffen Schwigon,,,
@@ -65,5 +77,21 @@ Steffen Schwigon,,,
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
 =cut
 
+
+__END__
+
+
