@@ -1,4 +1,10 @@
 package Tapper::Reports::Web::Controller::Tapper::Preconditions;
+BEGIN {
+  $Tapper::Reports::Web::Controller::Tapper::Preconditions::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Reports::Web::Controller::Tapper::Preconditions::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -83,20 +89,30 @@ sub new_create : Chained('base') :PathPart('create') :Args(0) :FormConfig
 }
 
 
+
+1;
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Reports::Web::Controller::Tapper::Preconditions - Catalyst Controller
+Tapper::Reports::Web::Controller::Tapper::Preconditions
 
 =head1 DESCRIPTION
 
 Catalyst Controller.
 
+=head1 NAME
+
+Tapper::Reports::Web::Controller::Tapper::Preconditions - Catalyst Controller
+
 =head1 METHODS
 
 =head2 index
 
-
-
 =head1 AUTHOR
 
 Steffen Schwigon,,,
@@ -105,6 +121,17 @@ Steffen Schwigon,,,
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
 =cut
 
-1;
