@@ -1,4 +1,10 @@
 package Tapper::Reports::Web::Controller::Tapper::Preconditions::Id;
+BEGIN {
+  $Tapper::Reports::Web::Controller::Tapper::Preconditions::Id::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Reports::Web::Controller::Tapper::Preconditions::Id::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -9,7 +15,7 @@ sub index :Path :Args(1)
 {
         my ( $self, $c, $id ) = @_;
         my $precondition : Stash;
-        
+
         my $precond_search = $c->model('TestrunDB')->resultset('Precondition')->find($id);
         if (not $precond_search) {
                 $c->response->body(qq(No precondition with id "$id" found in the database!));
@@ -20,28 +26,28 @@ sub index :Path :Args(1)
         return;
 }
 
+1;
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Reports::Web::Controller::Tapper::Preconditions - Catalyst Controller
-
-=head1 DESCRIPTION
-
-Catalyst Controller.
-
-=head1 METHODS
-
-=head2 index 
-
-
+Tapper::Reports::Web::Controller::Tapper::Preconditions::Id
 
 =head1 AUTHOR
 
-Steffen Schwigon,,,
+AMD OSRC Tapper Team <tapper@amd64.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This program is released under the following license: freebsd
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
 
 =cut
 
-1;
