@@ -1,4 +1,10 @@
 package Tapper::Reports::Web::Controller::Tapper::Reports::Tap;
+BEGIN {
+  $Tapper::Reports::Web::Controller::Tapper::Reports::Tap::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Reports::Web::Controller::Tapper::Reports::Tap::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -27,3 +33,27 @@ sub index :Path :Args(1)
 }
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Reports::Web::Controller::Tapper::Reports::Tap
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
