@@ -1,45 +1,62 @@
 package Tapper::Reports::Web::Controller::Tapper::Schedule;
+BEGIN {
+  $Tapper::Reports::Web::Controller::Tapper::Schedule::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Reports::Web::Controller::Tapper::Schedule::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
 use parent 'Catalyst::Controller';
 
-=head1 NAME
-
-Tapper::Reports::Web::Controller::Tapper::Schedule - Catalyst Controller
-
-=head1 DESCRIPTION
-
-Catalyst Controller.
-
-=head1 METHODS
-
-=cut
 
 
-=head2 index
-
-=cut
 
 sub index :Path :Args(0) {
     my ( $self, $c ) = @_;
 
     my $body = qx(tapper-testrun listqueue -v);
-    
+
     $c->response->body("<pre>
 $body
 </pre>");
 }
 
+1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Reports::Web::Controller::Tapper::Schedule
+
+=head1 DESCRIPTION
+
+Catalyst Controller.
+
+=head1 NAME
+
+Tapper::Reports::Web::Controller::Tapper::Schedule - Catalyst Controller
+
+=head1 METHODS
+
+=head2 index
 
 =head1 AUTHOR
 
-Maik Hentsche
+AMD OSRC Tapper Team <tapper@amd64.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This program is released under the following license: freebsd
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
 
 =cut
 
-1;
