@@ -1,4 +1,10 @@
 package Tapper::Reports::Web::Controller::Tapper::Testruns::IdList;
+BEGIN {
+  $Tapper::Reports::Web::Controller::Tapper::Testruns::IdList::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Reports::Web::Controller::Tapper::Testruns::IdList::VERSION = '4.0.1';
+}
 
 use 5.010;
 
@@ -8,20 +14,6 @@ use Tapper::Reports::Web::Util::Testrun;
 
 use parent 'Tapper::Reports::Web::Controller::Base';
 
-=head2 index
-
-Index function for /tapper/testruns/idlist/. Expects a comma separated
-list of testrun ids. The requested testruns are put into stash as has
-%testrunlist because we use the template /tapper/testruns/testrunlist.mas
-which expects this.
-
-@param string - comma separated ids
-
-@stash hash   - hash with key testruns => array of testrun hashes
-
-@return ignored
-
-=cut
 
 sub index :Path :Args(1)
 {
@@ -52,3 +44,40 @@ sub index :Path :Args(1)
 
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Reports::Web::Controller::Tapper::Testruns::IdList
+
+=head2 index
+
+Index function for /tapper/testruns/idlist/. Expects a comma separated
+list of testrun ids. The requested testruns are put into stash as has
+%testrunlist because we use the template /tapper/testruns/testrunlist.mas
+which expects this.
+
+@param string - comma separated ids
+
+@stash hash   - hash with key testruns => array of testrun hashes
+
+@return ignored
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
